==> nest-bootstraper-basic-0.0.0.tgz: package/index.js <==
/// <reference path="_ref.d.ts" />
var NestBasic = (function () {
    function NestBasic() {
        this.data = {};
    }
    return NestBasic;
})();

var NestBootstrap = (function () {
    function NestBootstrap() {
        this.steps = [];
        this.app = new NestBasic();
    }
    NestBootstrap.prototype.register = function (x) {
        this.steps.push(x);
        return this;
    };

    NestBootstrap.prototype.run = function (app, steps, i, add, sub) {
        var _this = this;
        if (steps.length > i) {
            var f = steps[i];

            if (Array.isArray(f)) {
                this.run(app, f, 0, add, sub);
                this.run(app, steps, i + 1, add, sub);
            } else {
                add();
                var fnext = steps.length == i + 1 ? sub : function () {
                    _this.run(app, steps, i + 1, add, sub);
                    sub();
                };

                var r = f(app, fnext);
                if (r !== true) {
                    if (r === undefined || r === app)
                        fnext();
                    else if (r === Object(r) && typeof r.then === "function")
                        r.then(fnext);
                    else
                        fnext();
                }
            }
        }
    };

    NestBootstrap.prototype.start = function (done) {
        var _this = this;
        var i = 0;
        var add = function () {
            i += 1;
        };

        if (done !== undefined) {
            var sub = function () {
                i -= 1;
                if (i === 0) {
                    _this.steps = [];
                    done(_this);
                }
            };
            this.run(this.app, this.steps, 0, add, sub);

            return undefined;
        } else {
            var d = this.app.q.defer();

            var sub = function () {
                i -= 1;
                if (i === 0) {
                    _this.steps = [];
                    d.resolve(_this);
                }
            };
            this.run(this.app, this.steps, 0, add, sub);

            return d.promise;
        }
    };
    NestBootstrap.prototype.continue = function () {
        this.run(this.app, this.steps, 0, function () {
        }, function () {
        });
        this.steps = [];
        return this;
    };
    return NestBootstrap;
})();

module.exports.NestBootstrap = NestBootstrap;

==> nest-bootstraper-basic-1.0.0.tgz: package/index.js <==
/// <reference path="_ref.d.ts" />
var NestBasic = (function () {
    function NestBasic() {
        this.modules = [];
    }
    return NestBasic;
})();

var NestBootstrap = (function () {
    function NestBootstrap() {
        this.steps = [];
        this.app = new NestBasic();
    }
    NestBootstrap.prototype.register = function (x) {
        this.steps.push(x);
    };

    NestBootstrap.prototype.run = function (app, steps, i, add, sub) {
        var _this = this;
        if (steps.length > i) {
            var f = steps[i];

            if (Array.isArray(f)) {
                this.run(app, f, 0, add, sub);
                this.run(app, steps, i + 1, add, sub);
            } else {
                add();

                var next = steps.length == i + 1 ? sub : function () {
                    _this.run(app, steps, i + 1, add, sub);
                    sub();
                };

                var fnext = next;

                var r = f(app, function () {
                    fnext();
                });

                if (r !== true) {
                    fnext = function () {
                    };

                    // this dance with fnext and next is done
                    // so if they retun not true and then call done
                    // it will do nothing and will not screw up the
                    if (r === undefined || r === app)
                        next();
                    else if (r === Object(r) && typeof r.then === "function")
                        r.then(next);
                    else
                        next();
                }
            }
        }
    };

    NestBootstrap.prototype.wait = function (done) {
        var _this = this;
        var i = 0;
        var add = function () {
            i += 1;
        };

        if (done !== undefined) {
            var sub = function () {
                i -= 1;
                if (i === 0) {
                    _this.steps = [];
                    done();
                }
            };
            this.run(this.app, this.steps, 0, add, sub);

            return undefined;
        } else {
            var qreg = this.app.modules.filter(function (v, i, a) {
                return v.name === 'IAsync';
            })[0];

            if (!qreg)
                throw "IAsync was not found in nest application";

            var q = qreg.instance;

            var d = q.defer();

            var sub = function () {
                i -= 1;
                if (i === 0) {
                    _this.steps = [];
                    d.resolve(_this);
                }
            };
            this.run(this.app, this.steps, 0, add, sub);

            return d.promise;
        }
    };
    NestBootstrap.prototype.start = function () {
        this.run(this.app, this.steps, 0, function () {
        }, function () {
        });
        this.steps = [];
    };
    return NestBootstrap;
})();

module.exports.NestBootstrap = NestBootstrap;
